@@ -3,7 +3,12 @@ import jinja2
 from jinja2.ext import Extension
 
 
-@jinja2.evalcontextfilter
+try:
+    from jinja2 import pass_eval_context as eval_context
+except ImportError:
+    from jinja2 import evalcontextfilter as eval_context
+
+@eval_context
 def from_json(eval_ctx, value):
     return json.loads(value)
 
